Dense Matrices
==============

.. automodule:: diofant.matrices.dense
   :members: MutableMatrix

Matrix Class Reference
----------------------

.. autoclass:: diofant.matrices.dense.DenseMatrix
   :members:
   :special-members:

.. autoclass:: diofant.matrices.dense.MutableDenseMatrix
   :members:

ImmutableMatrix Class Reference
-------------------------------

.. autoclass:: diofant.matrices.immutable.ImmutableMatrix
   :members:
   :noindex:
